==> amd-optimize-0.0.4.tgz: package/lib/parse.js <==
(function() {
  var acorn, parseRequireDefinitions, valuesFromArrayExpression, walk, _;

  _ = require("lodash");

  acorn = require("acorn");

  walk = require("acorn/util/walk");

  valuesFromArrayExpression = function(expr) {
    return expr.elements.map(function(a) {
      return a.value;
    });
  };

  module.exports = parseRequireDefinitions = function(config, file, callback) {
    var ast, definitions, err;
    try {
      ast = acorn.parse(file.stringContents, {
        sourceFile: file.relative,
        locations: config.sourceMap
      });
    } catch (_error) {
      err = _error;
      callback(err);
      return;
    }
    file.ast = ast;
    definitions = [];
    walk.ancestor(ast, {
      CallExpression: function(node, state) {
        var defineAncestors, deps, isInsideDefine, moduleName;
        if (node.callee.name === "define") {
          switch (node["arguments"].length) {
            case 1:
              if (node["arguments"][0].type === "FunctionExpression" && node["arguments"][0].params.length > 0) {
                deps = [];
                walk.simple(node["arguments"][0], {
                  VariableDeclaration: function(node) {
                    return node.declarations.forEach(function(_arg) {
                      var left, right;
                      left = _arg.id, right = _arg.init;
                      if (right.type === "CallExpression" && right.callee.name === "require") {
                        return deps.push(right["arguments"][0].value);
                      }
                    });
                  }
                });
              }
              break;
            case 2:
              switch (node["arguments"][0].type) {
                case "Literal":
                  moduleName = node["arguments"][0].value;
                  break;
                case "ArrayExpression":
                  deps = valuesFromArrayExpression(node["arguments"][0]);
              }
              break;
            case 3:
              moduleName = node["arguments"][0].value;
              deps = valuesFromArrayExpression(node["arguments"][1]);
          }
          definitions.push({
            method: "define",
            moduleName: moduleName,
            deps: deps != null ? deps : [],
            node: node
          });
          isInsideDefine = true;
        }
        if (node.callee.name === "require" && node["arguments"].length > 0 && node["arguments"][0].type === "ArrayExpression") {
          defineAncestors = _.any(state.slice(0, -1), function(ancestorNode) {
            return ancestorNode.type === "CallExpression" && (ancestorNode.callee.name === "define" || ancestorNode.callee.name === "require");
          });
          if (config.findNestedDependencies || !defineAncestors) {
            return definitions.push({
              method: "require",
              moduleName: void 0,
              deps: valuesFromArrayExpression(node["arguments"][0]),
              node: node
            });
          }
        }
      }
    });
    callback(null, file, definitions);
  };

}).call(this);

==> amd-optimize-0.2.4.tgz: package/lib/parse.js <==
(function() {
  var acorn, parseRequireDefinitions, valuesFromArrayExpression, walk, _;

  _ = require("lodash");

  acorn = require("acorn");

  walk = require("acorn/util/walk");

  valuesFromArrayExpression = function(expr) {
    return expr.elements.map(function(a) {
      return a.value;
    });
  };

  module.exports = parseRequireDefinitions = function(config, file, callback) {
    var ast, definitions, err;
    try {
      ast = acorn.parse(file.stringContents, {
        sourceFile: file.relative,
        locations: file.sourceMap != null
      });
    } catch (_error) {
      err = _error;
      if (err instanceof SyntaxError) {
        err.filename = file.path;
        err.message += " in " + file.path;
      }
      callback(err);
      return;
    }
    file.ast = ast;
    definitions = [];
    walk.ancestor(ast, {
      CallExpression: function(node, state) {
        var defineAncestors, deps, isInsideDefine, moduleName;
        if (node.callee.name === "define") {
          switch (node["arguments"].length) {
            case 1:
              if (node["arguments"][0].type === "FunctionExpression" && node["arguments"][0].params.length > 0) {
                deps = [];
                walk.simple(node["arguments"][0], {
                  CallExpression: function(node) {
                    if (node.callee.name === "require") {
                      return deps.push(node["arguments"][0].value);
                    }
                  }
                });
              }
              break;
            case 2:
              switch (node["arguments"][0].type) {
                case "Literal":
                  moduleName = node["arguments"][0].value;
                  break;
                case "ArrayExpression":
                  deps = valuesFromArrayExpression(node["arguments"][0]);
              }
              break;
            case 3:
              moduleName = node["arguments"][0].value;
              deps = valuesFromArrayExpression(node["arguments"][1]);
          }
          definitions.push({
            method: "define",
            moduleName: moduleName,
            deps: deps != null ? deps : [],
            node: node
          });
          isInsideDefine = true;
        }
        if (node.callee.name === "require" && node["arguments"].length > 0 && node["arguments"][0].type === "ArrayExpression") {
          defineAncestors = _.any(state.slice(0, -1), function(ancestorNode) {
            return ancestorNode.type === "CallExpression" && (ancestorNode.callee.name === "define" || ancestorNode.callee.name === "require");
          });
          if (config.findNestedDependencies || !defineAncestors) {
            return definitions.push({
              method: "require",
              moduleName: void 0,
              deps: valuesFromArrayExpression(node["arguments"][0]),
              node: node
            });
          }
        }
      }
    });
    callback(null, file, definitions);
  };

}).call(this);
